@@ -1,2 +1,2 @@
 from .databaseConnection import ClickConnection, MySqlConnection, SlackConnection, SSHTunnel, \
-    TgConnection, SlackConnection, BigQueryConnection
+    TgConnection, SlackConnection, BigQueryConnection, MySqlFinanceConnection, SSHFinanceTunnel
